@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "projectile" "20260109.1335"
+(define-package "projectile" "20260215.1443"
   "Manage and navigate projects in Emacs easily."
-  '((emacs "26.1"))
+  '((emacs  "27.1")
+    (compat "30"))
   :url "https://github.com/bbatsov/projectile"
-  :commit "f19262ae3f2764f10a4d087497058cdb9a0fd3df"
-  :revdesc "f19262ae3f27"
+  :commit "dd06dfd912656d41f2c63066aa8bacb898ddf7a2"
+  :revdesc "dd06dfd91265"
   :keywords '("project" "convenience")
   :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
